@@ -20,6 +20,7 @@
 #include <asm/sections.h>
 #include <asm/barebox-riscv-head.h>
 #include <asm/system.h>
+#include <asm/cache.h>
 
 unsigned long get_runtime_offset(void);
 
@@ -27,8 +28,6 @@ void setup_c(void);
 void relocate_to_current_adr(void);
 void relocate_to_adr(unsigned long target);
 
-void sync_caches_for_execution(void);
-
 void __noreturn __naked barebox_riscv_entry(unsigned long membase, unsigned long memsize,
 					    void *boarddata, unsigned int flags);
 
