@@ -1,4 +1,4 @@
-// SPDX-License-Identifier: GPL-2.0
+// SPDX-License-Identifier: GPL-2.0-only
 /*
  * address.c - address related devicetree functions
  *
@@ -125,8 +125,10 @@ static unsigned int of_bus_pci_get_flags(const __be32 *addr)
 	case 0x01:
 		flags |= IORESOURCE_IO;
 		break;
-	case 0x02: /* 32 bits */
 	case 0x03: /* 64 bits */
+		flags |= IORESOURCE_MEM_64;
+		/* fallthrough */
+	case 0x02: /* 32 bits */
 		flags |= IORESOURCE_MEM;
 		break;
 	}
