@@ -281,7 +281,6 @@ extern struct device_d *of_device_enable_and_register_by_name(const char *name);
 extern struct device_d *of_device_enable_and_register_by_alias(
 							const char *alias);
 
-extern struct device_d *of_device_create_on_demand(struct device_node *np);
 extern int of_device_ensure_probed(struct device_node *np);
 extern int of_device_ensure_probed_by_alias(const char *alias);
 extern int of_devices_ensure_probed_by_property(const char *property_name);
@@ -375,11 +374,6 @@ static inline void of_platform_device_dummy_drv(struct device_d *dev)
 {
 }
 
-static inline struct device_d *of_device_create_on_demand(struct device_node *np)
-{
-	return NULL;
-}
-
 static inline int of_device_ensure_probed(struct device_node *np)
 {
 	return 0;
